@@ -109,7 +109,7 @@ class Exceptions:
 
 class OpenSearchServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html)
     """
 
@@ -128,7 +128,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to accept an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#accept_inbound_connection)
         """
 
@@ -136,7 +136,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Attaches tags to an existing domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#add_tags)
         """
 
@@ -146,7 +146,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Associates a package with an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#associate_package)
         """
 
@@ -154,7 +154,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#can_paginate)
         """
 
@@ -165,7 +165,7 @@ class OpenSearchServiceClient(BaseClient):
         Cancels a scheduled service software update for an Amazon OpenSearch Service
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#cancel_service_software_update)
         """
 
@@ -173,26 +173,26 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         DomainName: str,
-        EngineVersion: str = None,
-        ClusterConfig: "ClusterConfigTypeDef" = None,
-        EBSOptions: "EBSOptionsTypeDef" = None,
-        AccessPolicies: str = None,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = None,
-        VPCOptions: "VPCOptionsTypeDef" = None,
-        CognitoOptions: "CognitoOptionsTypeDef" = None,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
-        AdvancedOptions: Mapping[str, str] = None,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = None,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = None,
-        TagList: Sequence["TagTypeDef"] = None,
-        AutoTuneOptions: "AutoTuneOptionsInputTypeDef" = None
+        EngineVersion: str = ...,
+        ClusterConfig: "ClusterConfigTypeDef" = ...,
+        EBSOptions: "EBSOptionsTypeDef" = ...,
+        AccessPolicies: str = ...,
+        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
+        VPCOptions: "VPCOptionsTypeDef" = ...,
+        CognitoOptions: "CognitoOptionsTypeDef" = ...,
+        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
+        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
+        AdvancedOptions: Mapping[str, str] = ...,
+        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
+        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
+        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
+        TagList: Sequence["TagTypeDef"] = ...,
+        AutoTuneOptions: "AutoTuneOptionsInputTypeDef" = ...
     ) -> CreateDomainResponseTypeDef:
         """
         Creates a new Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_domain)
         """
 
@@ -207,7 +207,7 @@ class OpenSearchServiceClient(BaseClient):
         Creates a new cross-cluster connection from a local OpenSearch domain to a
         remote OpenSearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_outbound_connection)
         """
 
@@ -217,12 +217,12 @@ class OpenSearchServiceClient(BaseClient):
         PackageName: str,
         PackageType: Literal["TXT-DICTIONARY"],
         PackageSource: "PackageSourceTypeDef",
-        PackageDescription: str = None
+        PackageDescription: str = ...
     ) -> CreatePackageResponseTypeDef:
         """
         Create a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.create_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_package)
         """
 
@@ -230,7 +230,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Permanently deletes the specified domain and all of its data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_domain)
         """
 
@@ -241,7 +241,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to delete an existing inbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_inbound_connection)
         """
 
@@ -252,7 +252,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the local domain owner to delete an existing outbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_outbound_connection)
         """
 
@@ -260,7 +260,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Deletes the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_package)
         """
 
@@ -269,18 +269,18 @@ class OpenSearchServiceClient(BaseClient):
         Returns domain configuration information about the specified domain, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain)
         """
 
     def describe_domain_auto_tunes(
-        self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
+        self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
         Provides scheduled Auto-Tune action details for the domain, such as Auto-Tune
         action type, description, severity, and scheduled date.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_auto_tunes)
         """
 
@@ -289,7 +289,7 @@ class OpenSearchServiceClient(BaseClient):
         Provides cluster configuration information about the specified domain, such as
         the state, creation date, update version, and update date for cluster options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_config)
         """
 
@@ -298,21 +298,21 @@ class OpenSearchServiceClient(BaseClient):
         Returns domain configuration information about the specified domains, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domains)
         """
 
     def describe_inbound_connections(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeInboundConnectionsResponseTypeDef:
         """
         Lists all the inbound cross-cluster connections for a remote domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_inbound_connections)
         """
 
@@ -321,65 +321,61 @@ class OpenSearchServiceClient(BaseClient):
         *,
         InstanceType: OpenSearchPartitionInstanceTypeType,
         EngineVersion: str,
-        DomainName: str = None
+        DomainName: str = ...
     ) -> DescribeInstanceTypeLimitsResponseTypeDef:
         """
         Describe the limits for a given instance type and OpenSearch or Elasticsearch
         version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_instance_type_limits)
         """
 
     def describe_outbound_connections(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribeOutboundConnectionsResponseTypeDef:
         """
         Lists all the outbound cross-cluster connections for a local domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_outbound_connections)
         """
 
     def describe_packages(
         self,
         *,
-        Filters: Sequence["DescribePackagesFilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Filters: Sequence["DescribePackagesFilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> DescribePackagesResponseTypeDef:
         """
         Describes all packages available to Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_packages)
         """
 
     def describe_reserved_instance_offerings(
-        self,
-        *,
-        ReservedInstanceOfferingId: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        self, *, ReservedInstanceOfferingId: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeReservedInstanceOfferingsResponseTypeDef:
         """
         Lists available reserved OpenSearch instance offerings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instance_offerings)
         """
 
     def describe_reserved_instances(
-        self, *, ReservedInstanceId: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, ReservedInstanceId: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeReservedInstancesResponseTypeDef:
         """
         Returns information about reserved OpenSearch instances for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instances)
         """
 
@@ -389,52 +385,52 @@ class OpenSearchServiceClient(BaseClient):
         """
         Dissociates a package from the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#dissociate_package)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#generate_presigned_url)
         """
 
     def get_compatible_versions(
-        self, *, DomainName: str = None
+        self, *, DomainName: str = ...
     ) -> GetCompatibleVersionsResponseTypeDef:
         """
         Returns a list of upgrade-compatible versions of OpenSearch/Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_compatible_versions)
         """
 
     def get_package_version_history(
-        self, *, PackageID: str, MaxResults: int = None, NextToken: str = None
+        self, *, PackageID: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
         Returns a list of package versions, along with their creation time and commit
         message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_package_version_history)
         """
 
     def get_upgrade_history(
-        self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
+        self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
         Retrieves the complete history of the last 10 upgrades performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_history)
         """
 
@@ -443,27 +439,27 @@ class OpenSearchServiceClient(BaseClient):
         Retrieves the latest status of the last upgrade or upgrade eligibility check
         performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_status)
         """
 
     def list_domain_names(
-        self, *, EngineType: EngineTypeType = None
+        self, *, EngineType: EngineTypeType = ...
     ) -> ListDomainNamesResponseTypeDef:
         """
         Returns the names of all domains owned by the current user's account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domain_names)
         """
 
     def list_domains_for_package(
-        self, *, PackageID: str, MaxResults: int = None, NextToken: str = None
+        self, *, PackageID: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListDomainsForPackageResponseTypeDef:
         """
         Lists all Amazon OpenSearch Service domains associated with the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domains_for_package)
         """
 
@@ -471,9 +467,9 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         EngineVersion: str,
-        DomainName: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        DomainName: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListInstanceTypeDetailsResponseTypeDef:
         """
         See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/opense
@@ -481,17 +477,17 @@ class OpenSearchServiceClient(BaseClient):
         client.list_instance_type_details( EngineVersion='string', DomainName='string',
         MaxResults=123, NextToken='stri...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_instance_type_details)
         """
 
     def list_packages_for_domain(
-        self, *, DomainName: str, MaxResults: int = None, NextToken: str = None
+        self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListPackagesForDomainResponseTypeDef:
         """
         Lists all packages associated with the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_packages_for_domain)
         """
 
@@ -499,27 +495,27 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns all tags for the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_tags)
         """
 
     def list_versions(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListVersionsResponseTypeDef:
         """
         List all supported versions of OpenSearch and Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_versions)
         """
 
     def purchase_reserved_instance_offering(
-        self, *, ReservedInstanceOfferingId: str, ReservationName: str, InstanceCount: int = None
+        self, *, ReservedInstanceOfferingId: str, ReservationName: str, InstanceCount: int = ...
     ) -> PurchaseReservedInstanceOfferingResponseTypeDef:
         """
         Allows you to purchase reserved OpenSearch instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#purchase_reserved_instance_offering)
         """
 
@@ -530,7 +526,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to reject an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#reject_inbound_connection)
         """
 
@@ -538,7 +534,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Removes the specified set of tags from the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#remove_tags)
         """
 
@@ -548,7 +544,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Schedules a service software update for an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#start_service_software_update)
         """
 
@@ -556,25 +552,25 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         DomainName: str,
-        ClusterConfig: "ClusterConfigTypeDef" = None,
-        EBSOptions: "EBSOptionsTypeDef" = None,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = None,
-        VPCOptions: "VPCOptionsTypeDef" = None,
-        CognitoOptions: "CognitoOptionsTypeDef" = None,
-        AdvancedOptions: Mapping[str, str] = None,
-        AccessPolicies: str = None,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = None,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = None,
-        AutoTuneOptions: "AutoTuneOptionsTypeDef" = None
+        ClusterConfig: "ClusterConfigTypeDef" = ...,
+        EBSOptions: "EBSOptionsTypeDef" = ...,
+        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
+        VPCOptions: "VPCOptionsTypeDef" = ...,
+        CognitoOptions: "CognitoOptionsTypeDef" = ...,
+        AdvancedOptions: Mapping[str, str] = ...,
+        AccessPolicies: str = ...,
+        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
+        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
+        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
+        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
+        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
+        AutoTuneOptions: "AutoTuneOptionsTypeDef" = ...
     ) -> UpdateDomainConfigResponseTypeDef:
         """
         Modifies the cluster configuration of the specified domain, such as setting the
         instance type and the number of instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_domain_config)
         """
 
@@ -583,13 +579,13 @@ class OpenSearchServiceClient(BaseClient):
         *,
         PackageID: str,
         PackageSource: "PackageSourceTypeDef",
-        PackageDescription: str = None,
-        CommitMessage: str = None
+        PackageDescription: str = ...,
+        CommitMessage: str = ...
     ) -> UpdatePackageResponseTypeDef:
         """
         Updates a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.update_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_package)
         """
 
@@ -598,13 +594,13 @@ class OpenSearchServiceClient(BaseClient):
         *,
         DomainName: str,
         TargetVersion: str,
-        PerformCheckOnly: bool = None,
-        AdvancedOptions: Mapping[str, str] = None
+        PerformCheckOnly: bool = ...,
+        AdvancedOptions: Mapping[str, str] = ...
     ) -> UpgradeDomainResponseTypeDef:
         """
         Allows you to either upgrade your domain or perform an upgrade eligibility check
         to a compatible version of OpenSearch or Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#upgrade_domain)
         """
